@@ -11,7 +11,9 @@ import requests
 import click
 from virtualenvapi.manage import VirtualEnvironment
 from virtualenv import cli_run
-from nubium_utils._local_env_defaults import local_dotenv_dict
+from nubium_utils import _local_env_defaults as nubium_utils_vars
+from functools import wraps, partial
+import asyncio
 
 
 def download_file(url, dest: Path, replace_existing=False):
@@ -29,44 +31,42 @@ def download_file(url, dest: Path, replace_existing=False):
 
 
 def read_file(file):
-    with open(file, 'r') as f:
+    with open(file, "r") as f:
         file_out = f.readlines()
     return file_out
 
 
 def write_file(line_list, file):
-    with open(file, 'w') as f:
+    with open(file, "w") as f:
         f.writelines(line_list)
 
 
-def has_requirements():
-    return Path('requirements.in').is_file()
+def has_requirements_in():
+    return Path("requirements.in").is_file()
 
 
 def is_nubium_app():
-    # TODO: Turn this into a decorator?
-    return Path('app.py').is_file()
+    return Path("app.py").is_file()
 
 
 def is_faust_app():
-    return Path('kiwf_openshift_health_check.py').is_file()
+    return Path("kiwf_openshift_health_check.py").is_file()
 
 
 def import_dotenvs():
-    if environ.get('DUDE_CONFIG_DOTENV'):
-        load_dotenv(environ['DUDE_CONFIG_DOTENV'])
+    if environ.get("DUDE_CONFIG_DOTENV"):
+        load_dotenv(environ["DUDE_CONFIG_DOTENV"])
     else:
-        load_dotenv(f'{Path(__file__).parent}/config.env')
-    environ.update(local_dotenv_dict)
+        load_dotenv(f"{Path(__file__).parent}/config.env")
+    load_dotenv(f"{Path(nubium_utils_vars.__file__).parent}/local.env")
 
-    override = bool(environ.get('DUDE_ALLOW_DOTENV_OVERRIDE'))
-    for var in ['DUDE_CREDENTIALS_DOTENV', 'DUDE_NUBIUM_DOTENV', 'DUDE_CUSTOM_DOTENV']:
+    override = bool(environ.get("DUDE_ALLOW_DOTENV_OVERRIDE"))
+    for var in ["DUDE_CREDENTIALS_DOTENV", "DUDE_NUBIUM_DOTENV", "DUDE_CUSTOM_DOTENV"]:
         if environ.get(var):
             load_dotenv(environ[var], override=override)
 
 
 def sync_virtual_environment(wipe_existing=False):
-    # TODO load virtualenv path from configuration
     venv_path = Path(f'{environ["DUDE_APP_VENV"]}')
     if wipe_existing:
         rmtree(venv_path)
@@ -78,17 +78,13 @@ def sync_virtual_environment(wipe_existing=False):
         # TODO lock versions of pip-tools and dependencies
         run_command_in_virtual_environment("pip", args=["install", "pip-tools"])
     run_command_in_virtual_environment("pip-sync")
-    local_dotenv = Path('configs/local.env')
-    venv_dotenv = Path(f'{venv_path}/.env')
+    local_dotenv = Path("configs/local.env")
+    venv_dotenv = Path(f"{venv_path}/.env")
     if local_dotenv.is_file() and not venv_dotenv.is_file():
         copy2(local_dotenv, venv_dotenv)
 
 
-def run_command_in_virtual_environment(
-    command: str = '',
-    venv_path: Path = None,
-    args: List[str] = None
-):
+def run_command_in_virtual_environment(command: str = "", venv_path: Path = None, args: List[str] = None):
     if not venv_path:
         venv_path = Path(f'{environ["DUDE_APP_VENV"]}')
     if not args:
@@ -128,3 +124,16 @@ def run_command_in_pseudo_tty(
     os.close(slave_fd)  # can't do it sooner: it leads to errno.EIO error
     os.close(master_fd)
     proc.wait()
+
+
+def as_async(func):
+    """
+    Turn any method into an async method by making a new, decorated method with this.
+    """
+    @wraps(func)
+    async def run_as_async(*args, loop=None, executor=None, **kwargs):
+        if loop is None:
+            loop = asyncio.get_event_loop()
+        pfunc = partial(func, *args, **kwargs)
+        return await loop.run_in_executor(executor, pfunc)
+    return run_as_async
